@@ -12,7 +12,7 @@ def setup():
     http_connection.ON_DISCONNECTED = on_disconnect
 
     # shutdown handler for connection
-    shutdown.register_func(http_connection.stop_connection, msg='Stopping openHAB connection')
+    shutdown.register_func(http_connection.shutdown_connection, msg='Stopping openHAB connection')
 
     # shutdown handler for plugins
     shutdown.register_func(on_disconnect, msg='Stopping openHAB plugins')
@@ -23,4 +23,4 @@ def setup():
 
 
 async def start():
-    await http_connection.start_connection()
+    await http_connection.setup_connection()
