@@ -1,13 +1,12 @@
 from typing import Callable
 
+from HABApp.core.internals.wrapped_function import WrappedFunctionBase
 from eascheduler.executors import ExecutorBase
 
-from HABApp.core import WrappedFunction
-
 
 class WrappedFunctionExecutor(ExecutorBase):
     def __init__(self, func: Callable, *args, **kwargs):
-        assert isinstance(func, WrappedFunction), type(func)
+        assert isinstance(func, WrappedFunctionBase), type(func)
         super().__init__(func, *args, **kwargs)
 
     def execute(self):
